@@ -59,7 +59,8 @@ def command(commandString: str,
 
 def get(isPollinationModel: Optional[bool] = False, 
     syncToken: Optional[str] = "",
-    key : str = None) -> str:
+    key : str = None,
+    platform: str = 'Rhino') -> str:
     """Create a new instance of "button.get".
 
     Parameters
@@ -73,7 +74,9 @@ def get(isPollinationModel: Optional[bool] = False,
         An optional key that uniquely identifies this component. If this is
         None, and the component's arguments are changed, the component will
         be re-mounted in the Streamlit frontend and lose its current state.
-
+    platform: str
+        A key that uniquely identifies the host software. 
+        Supported values: Rhino, Sketchup. Default value is Rhino.
     Returns
     -------
     string
@@ -82,7 +85,8 @@ def get(isPollinationModel: Optional[bool] = False,
     component_value = _component_func_get(isPollinationModel=isPollinationModel, 
         syncToken=syncToken,
         key=key, 
-        default=None)
+        default=None,
+        platform=platform)
 
     return component_value
 
@@ -90,7 +94,8 @@ def send(action: str,
     data: Union[dict, List[dict]], 
     uniqueId: str, 
     options: Optional[dict] = {},
-    key=None) -> str:
+    key: str = None,
+    platform: str = 'Rhino') -> str:
     """Create a new instance of "button.send".
 
     Parameters
@@ -121,6 +126,10 @@ def send(action: str,
         An optional key that uniquely identifies this component. If this is
         None, and the component's arguments are changed, the component will
         be re-mounted in the Streamlit frontend and lose its current state.
+    
+    platform: str
+        A key that uniquely identifies the host software. 
+        Supported values: Rhino, Sketchup. Default value is Rhino.
 
     Returns
     -------
@@ -133,11 +142,12 @@ def send(action: str,
         uniqueId=uniqueId,
         options=options,
         key=key, 
-        default="NAN")
+        default="NAN",
+        platform=platform)
 
     return component_value
 
-if not _RELEASE:
+if _RELEASE:
     import streamlit as st
     import json
 
@@ -176,20 +186,27 @@ if not _RELEASE:
         key="secret-key-2")
     
     st.write("Command in action: %s !" % command_active)
-    
     st.write(data_to_pass)
 
-    command_model = send("BakePollinationModel",
-        {}, "my-secret-key", key="secret-key-3")
-
-    
     st.subheader("Pollination, Get Geometry Button")
     geometry = get(key="secret-key-4")
-    st.write(geometry)
+    if geometry:
+        st.write(json.loads(geometry))
 
-    st.subheader("Pollination, Get Pollination Model Button")
-    model = get(isPollinationModel=True, key="secret-key-4")
-    st.write(model)
+    host_software = st.selectbox(
+     "Host software?",
+     ("Rhino", "Sketchup"))
 
+    print(host_software)
+    st.subheader("Pollination, Get/Send Pollination Model Button")
+    model = get(isPollinationModel=True, 
+        key="secret-key-5", 
+        platform=host_software)
+    if model:
+        json_model = json.loads(model)
+        st.write(json_model)
+    if model and host_software == "Rhino":
+        command_model = send("BakePollinationModel",
+            json_model, "my-secret-key", key="secret-key-3")
 
     
\ No newline at end of file
