@@ -72,7 +72,8 @@ def settings(
                     'lat': 41.2324,
                     'lon': 12.3234
                 },
-                units: 1
+                units: 1,
+                layers: ['Streamlit', 'JS', 'Python']
             }
         
         - Where Units mapping:
@@ -81,6 +82,7 @@ def settings(
             - Meters = 4
             - Inches = 8
             - Feet = 9
+        - layers array contains layers to create
 
     defaultChecked: bool
         Set if it has to be checked by default.
@@ -140,10 +142,11 @@ if not _RELEASE:
                 'lat': 41.2324,
                 'lon': 12.3234
             },
-            'units': 2
+            'units': 2,
+            'layers': ['Streamlit', 'JS']
         }
 
     test = settings(
-        data=sync_token_2,
+        data=data,
         defaultChecked=True)
     st.write(test)
\ No newline at end of file
